@@ -5,10 +5,7 @@ tm1_create_subset <- function(tm1_connection,
                             mdx = "",
                             overwrite = TRUE) {
 
-  tm1_adminhost <- tm1_connection$adminhost
-  tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
-  tm1_ssl <- tm1_connection$ssl
   tm1_base_url <- tm1_connection$base_url
 
   # Check if subset exist
@@ -31,11 +28,6 @@ tm1_create_subset <- function(tm1_connection,
 
   if (subsetexist == FALSE){
 
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/Dimensions('"
   u7 <- dimension
   u8 <- "')/Hierarchies('"
@@ -44,7 +36,7 @@ tm1_create_subset <- function(tm1_connection,
 
 
   # url development
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10), paste0(tm1_base_url, u6, u7, u8, u9, u10))
+  url <- paste0(tm1_base_url, u6, u7, u8, u9, u10)
   #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/Subsets"
 
   if (mdx != "") {
@@ -105,11 +97,6 @@ tm1_create_subset <- function(tm1_connection,
     # added because some http does not know space
     subset <- gsub(" ", "%20", subset, fixed=TRUE)
 
-    u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-    u2 <- tm1_adminhost
-    u3 <- ":"
-    u4 <- tm1_httpport
-    u5 <- "/"
     u6 <- "api/v1/Dimensions('"
     u7 <- dimension
     u8 <- "')/Hierarchies('"
@@ -120,7 +107,7 @@ tm1_create_subset <- function(tm1_connection,
 
 
     # url development
-    url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10, u11, u12), paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12))
+    url <- paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12)
     #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/Subsets('test')"
 
     elementbody <- "{ \"Expression\":\" \"}"
