@@ -3,10 +3,7 @@ tm1_delete_element <- function(tm1_connection,
                             element,
                             parent = "") {
 
-  tm1_adminhost <- tm1_connection$adminhost
-  tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
-  tm1_ssl <- tm1_connection$ssl
   tm1_base_url <- tm1_connection$base_url
 
   # added because some http does not know space
@@ -19,11 +16,6 @@ tm1_delete_element <- function(tm1_connection,
 
   if (parent == "") {
 
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/Dimensions('"
   u7 <- dimension
   u8 <- "')/Hierarchies('"
@@ -34,7 +26,7 @@ tm1_delete_element <- function(tm1_connection,
 
 
   # url development
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10, u11, u12), paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12))
+  url <- paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12)
   #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/Elements('test')"
 
   # delete request
@@ -67,11 +59,6 @@ tm1_delete_element <- function(tm1_connection,
 
   else {
 
-    u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-    u2 <- tm1_adminhost
-    u3 <- ":"
-    u4 <- tm1_httpport
-    u5 <- "/"
     u6 <- "api/v1/Dimensions('"
     u7 <- dimension
     u8 <- "')/Hierarchies('"
@@ -84,7 +71,7 @@ tm1_delete_element <- function(tm1_connection,
 
 
     # url development
-    url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10, u11, u12, u13, u14), paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12, u13, u14))
+    url <- paste0(tm1_base_url, u6, u7, u8, u9, u10, u11, u12, u13, u14)
     #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/
     #Edges(ParentName='TheActualParent'sName', ComponentName='TheActualComponent'sName')"
 
