@@ -1,46 +1,71 @@
 tm1_send_dataset <- function(tm1_connection,
                           valueset, cube, rowdim, coldim,
+                          rowdim2 = "", rowdim3 = "", rowdim4 = "", rowdim5 = "",
                           titledim1 = "", titleel1 = "", titledim2 = "", titleel2 = "",
                           titledim3 = "", titleel3 = "", titledim4 = "", titleel4 = "",
                           titledim5 = "", titleel5 = "", titledim6 = "", titleel6 = "",
                           titledim7 = "", titleel7 = "", titledim8 = "", titleel8 = ""
                           ) {
 
-  tm1_adminhost <- tm1_connection$adminhost
-  tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
-  tm1_ssl <- tm1_connection$ssl
   tm1_base_url <- tm1_connection$base_url
 
   ###########################################
   ###########mdx generate
-  mdx <- tm1_create_mdx(cube,
-                   rowdim1 = rowdim, rowel1 = paste(rownames(valueset), collapse = '|'),
-                   coldim1 = coldim, colel1 = paste(colnames(valueset), collapse = '|'),
-                   titledim1 = titledim1, titleel1 = titleel1,
-                   titledim2 = titledim2, titleel2 = titleel2,
-                   titledim3 = titledim3, titleel3 = titleel3,
-                   titledim4 = titledim4, titleel4 = titleel4,
-                   titledim5 = titledim5, titleel5 = titleel5,
-                   titledim6 = titledim6, titleel6 = titleel6,
-                   titledim7 = titledim7, titleel7 = titleel7,
-                   titledim8 = titledim8, titleel8 = titleel8,
-                   rowsuppress = FALSE, colsuppress = FALSE)
+
+  mdxselect <- "Select {"
+
+  ### row mdx build
+  mdxrown <- nrow(valueset)
+  mdxrowlist <- strsplit(rownames(valueset), "|", TRUE)
+  mdxrowlist2 <- character(mdxrown)
+  for (i in 1:mdxrown) {
+    mdxrowlist[[i]][1] <- ifelse(rowdim != "", paste0( "[", rowdim, "].[", mdxrowlist[[i]][1], "]"), "")
+    mdxrowlist[[i]][2] <- ifelse(rowdim2 != "", paste0( "[", rowdim2, "].[", mdxrowlist[[i]][2], "]"), "")
+    mdxrowlist[[i]][3] <- ifelse(rowdim3 != "", paste0( "[", rowdim3, "].[", mdxrowlist[[i]][3], "]"), "")
+    mdxrowlist[[i]][4] <- ifelse(rowdim4 != "", paste0( "[", rowdim4, "].[", mdxrowlist[[i]][4], "]"), "")
+    mdxrowlist[[i]][5] <- ifelse(rowdim5 != "", paste0( "[", rowdim5, "].[", mdxrowlist[[i]][5], "]"), "")
+
+    mdxrowlisttemp <- mdxrowlist[[i]]
+
+    mdxrowlist2[i] <- paste0( "{", paste(mdxrowlisttemp[mdxrowlisttemp != ""], collapse = "}*{"), "}")
+  }
+
+  mdxrows <- paste(mdxrowlist2, collapse = ",")
+
+  mdxrowend <- "} ON ROWS,{"
+
+  ### column mdx build
+  mdxcols <- paste0("[", coldim, "].[",paste(colnames(valueset), collapse = paste0("],[", coldim, "].[")),"]")
+
+  mdxcolend <- "} ON COLUMNS "
+
+  mdxcube <- paste0("FROM [", cube, "]")
+
+  mdxwherelist <- character(0)
+  mdxwherelist[1] <- ifelse(titledim1 != "", paste0("[", titledim1, "].[", titleel1, "]"), "")
+  mdxwherelist[2] <- ifelse(titledim2 != "", paste0("[", titledim2, "].[", titleel2, "]"), "")
+  mdxwherelist[3] <- ifelse(titledim3 != "", paste0("[", titledim3, "].[", titleel3, "]"), "")
+  mdxwherelist[4] <- ifelse(titledim4 != "", paste0("[", titledim4, "].[", titleel4, "]"), "")
+  mdxwherelist[5] <- ifelse(titledim5 != "", paste0("[", titledim5, "].[", titleel5, "]"), "")
+  mdxwherelist[6] <- ifelse(titledim6 != "", paste0("[", titledim6, "].[", titleel6, "]"), "")
+  mdxwherelist[7] <- ifelse(titledim7 != "", paste0("[", titledim7, "].[", titleel7, "]"), "")
+  mdxwherelist[8] <- ifelse(titledim8 != "", paste0("[", titledim8, "].[", titleel8, "]"), "")
+
+  mdxwhere <- paste0(" WHERE (", paste(mdxwherelist[mdxwherelist != ""], collapse = ','), ")")
+
+
+  mdx <- paste0(mdxselect, mdxrows, mdxrowend, mdxcols, mdxcolend, mdxcube, mdxwhere)
 
   ###########################################
   ########### construct mdx to get id
 
   # url development
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/ExecuteMDX"
   #u6 <- "?$expand=Axes($expand=Tuples($expand=Members($select=Name,UniqueName))),Cells($select=Value)"
   u7 <- ""
 
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7), paste0(tm1_base_url, u6, u7))
+  url <- paste0(tm1_base_url, u6, u7)
   #url = "https://localhost:8881/api/v1/ExecuteMDX?
   #$expand=Axes($expand=Tuples($expand=Members($select=Name))),Cells($select=Value)"
 
@@ -67,16 +92,11 @@ tm1_send_dataset <- function(tm1_connection,
   ###########################################
   ########### SEnd the values
   # url development
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/Cellsets('"
   u7 <- CellSetID
   u8 <- "')/Cells"
 
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8), paste0(tm1_base_url, u6, u7, u8))
+  url <- paste0(tm1_base_url, u6, u7, u8)
 
   # change body to values
   nrown <- nrow(valueset)
@@ -124,16 +144,11 @@ tm1_send_dataset <- function(tm1_connection,
   ###########################################
   ###########Delete the CellSet
   # url development
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/Cellsets('"
   u7 <- CellSetID
   u8 <- "')"
 
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8), paste0(tm1_base_url, u6, u7, u8))
+  url <- paste0(tm1_base_url, u6, u7, u8)
 
   #Delete request
   tm1_process_return <-
